pub type AllPalletsWithoutSystem = (PalletFoo, PalletAuthor);Expand description
All pallets included in the runtime as a nested tuple of types. Excludes the System pezpallet.
pub type AllPalletsWithoutSystem = (PalletFoo, PalletAuthor);All pallets included in the runtime as a nested tuple of types. Excludes the System pezpallet.